package com.diagbot.repository;

import com.diagbot.entity.node.Dept;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;
import org.springframework.data.repository.query.Param;

import java.util.List;


public interface DeptRepository extends Neo4jRepository<Dept, Long> {

    List<Dept> findByNameContaining(String name);

    List<Dept> findByNameIs(String name);

    Page<Dept> findByNameContainingIgnoreCaseOrPycodeContainingIgnoreCase(String name, String pycode, Pageable pageable);

    @Query("MATCH (n:`科室`)-[r]-(m) WHERE toLower(n.`name`) = toLower($name) \n" +
            "OR toLower(n.`拼音编码`) = toLower($pycode)  \n" +
            "RETURN n, collect(r), collect(m)\n" +
            "union\n" +
            "MATCH (n:`科室`)-[r]-(m) WHERE toLower(n.`name`) starts with toLower($name) \n" +
            "OR toLower(n.`拼音编码`) starts with toLower($pycode)  \n" +
            "RETURN n, collect(r), collect(m) limit 100\n" +
            "union\n" +
            "MATCH (n:`科室`)-[r]-(m) WHERE toLower(n.`name`) CONTAINS toLower($name) \n" +
            "OR toLower(n.`拼音编码`) CONTAINS toLower($pycode)  \n" +
            "RETURN n, collect(r), collect(m) limit $size")
    List<Dept> index(@Param("name") String name, @Param("pycode") String pycode, @Param("size") Integer size);
}
