package com.diagbot.repository;

import com.diagbot.entity.node.LisName;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;
import org.springframework.data.repository.query.Param;

import java.util.List;


public interface LisNameRepository extends Neo4jRepository<LisName, Long> {

    List<LisName> findByNameIs(String name);

    List<LisName> findByNameContaining(String name);

    List<LisName> findByNameIn(List<String> names);

    Page<LisName> findByNameContainingIgnoreCaseOrPycodeContainingIgnoreCase(String name, String pycode, Pageable pageable);

    @Query("MATCH (n:`实验室检查名称`)-[r]-(m) WHERE n.`静态知识标识` = $isKL \n" +
            "AND (toLower(n.`name`) = toLower($name)  OR  toLower(n.`拼音编码`) = toLower($pycode))\n" +
            "RETURN n, collect(r), collect(m)\n" +
            "UNION\n" +
            "MATCH (n:`实验室检查名称`)-[r]-(m) WHERE n.`静态知识标识` = $isKL \n" +
            "AND (toLower(n.`name`) STARTS WITH toLower($name) OR toLower(n.`拼音编码`) STARTS WITH toLower($pycode))\n" +
            "RETURN n, collect(r), collect(m) limit $size\n" +
            "UNION \n" +
            "MATCH (n:`实验室检查名称`)-[r]-(m) WHERE n.`静态知识标识` = $isKL  \n" +
            "AND (toLower(n.`name`) CONTAINS toLower($name) OR toLower(n.`拼音编码`) CONTAINS toLower($pycode))  \n" +
            "RETURN n, collect(r), collect(m) limit $size")
    List<LisName> staticKnowledgeIndex(@Param("isKL") Integer isKL, @Param("name") String name, @Param("pycode") String pycode, @Param("size") Integer size);

    @Query("MATCH (n:`实验室检查名称`)-[r]-(m) WHERE toLower(n.`name`) = toLower($name) \n" +
            "OR toLower(n.`拼音编码`) = toLower($pycode)  \n" +
            "RETURN n, collect(r), collect(m)\n" +
            "union\n" +
            "MATCH (n:`实验室检查名称`)-[r]-(m) WHERE toLower(n.`name`) starts with toLower($name) \n" +
            "OR toLower(n.`拼音编码`) starts with toLower($pycode)  \n" +
            "RETURN n, collect(r), collect(m) limit 100\n" +
            "union\n" +
            "MATCH (n:`实验室检查名称`)-[r]-(m) WHERE toLower(n.`name`) CONTAINS toLower($name) \n" +
            "OR toLower(n.`拼音编码`) CONTAINS toLower($pycode)  \n" +
            "RETURN n, collect(r), collect(m) limit $size")
    List<LisName> index(@Param("name") String name, @Param("pycode") String pycode, @Param("size") Integer size);
}
